# Nexmo CLI

[![npm version](https://badge.fury.io/js/nexmo-cli.svg)](https://badge.fury.io/js/nexmo-cli) [![Build Status](https://travis-ci.org/Nexmo/nexmo-cli.svg?branch=master)](https://travis-ci.org/Nexmo/nexmo-cli)
[![Known Vulnerabilities](https://snyk.io/test/github/Nexmo/nexmo-cli/badge.svg)](https://snyk.io/test/github/Nexmo/nexmo-cli)

[Installation](#installation) | [Usage](#usage) | [Contributing](#contributing) | [License](#license)

## Installation

The Nexmo CLI requires Node.js 6 or above. If you don't have Node.js installed on your system, go to https://nodejs.org/en/download/ and download the appropriate installer for your system.

With Node.js installed, you can then install the `nexmo-cli` package from the npm registry.

```
npm install nexmo-cli@beta -g
```

> If you see an `EACCES` error when you try to install a package globally, follow the steps outlined at [_How to Prevent Permissions Errors_](https://docs.npmjs.com/getting-started/fixing-npm-permissions).

By default, the CLI will read your [Nexmo](https://dashboard.nexmo.com/settings) API key and secret from the `NEXMO_API_KEY` and `NEXMO_API_SECRET` environment variables. For example, to get your balance:

```bash
NEXMO_API_KEY=1234 NEXMO_API_SECRET=abcd nexmo balance
```

Alternatively, you can save your API key and secret by using the following command:

```bash
> nexmo setup <api_key> <api_secret>
Credentials written to /Users/yourname/.nexmorc
```

This will save your credentials to `~/.nexmorc`. If you want to use different credentials per project, you can pass the `--local` flag as follows:

```bash
> nexmo setup <api_key> <api_secret> --local
```

This will save the config to your local folder instead.

## Usage

[Flags](#flags) | [Account](#account) | [Pricing](#pricing) | [Numbers](#numbers) | [SMS](#sms) | [Applications](#applications) | [Conversations](#conversations) | [Users](#users) | [Members](#members) | [Linking](#linking) | [Insight](#insight) | [JWT](#jwt)

### Flags

Use `--quiet` to silence all but errors and warnings, and use `--verbose` to get more detailed output.

### Account

#### Account login

```bash
> nexmo setup <api_key> <api_secret>
Credentials written to /home/username/.nexmorc
```

Alias: `nexmo s`.

#### Account info

```bash
> nexmo account
API Key:    <api_key>
API Secret: <api_secret>
```

#### Account balance

```bash
> nexmo balance
18.96 EUR

> nexmo balance -v
18.9589 EUR
```

Alias: `nexmo b`

### Pricing

#### Price to send an SMS to a number

```bash
> nexmo price:sms 44555555555
0.03140000 EUR
```

Alias: `nexmo ps`

#### Price to make a call to a number

```bash
> nexmo price:voice 44555555555
0.02400000 EUR
```

Alias: `nexmo pv`

#### Price for outbound SMS per country

```bash
> nexmo price:country GB
0.03140000 EUR

> nexmo price:country LU -v

network           | mtPrice
------------------------------
POST Luxembourg   | 0.01280000
Orange Luxembourg | 0.01280000
Join Experience   | 0.01280000
Tango             | 0.01280000
```

Alias: `nexmo pc`

### Numbers

#### List all numbers on your account

- Optional flags:

  - `--size` The amount of results to return
  - `--page` The page of results to return
  - `--pattern <pattern>` to be matched in number (use * to match end or start of number)

```bash
> nexmo numbers:list
31555555555
44655555555
44555555555

> nexmo numbers:list --verbose
Item 1-3 of 3

msisdn      | country | type       | features  | voiceCallbackType | voiceCallbackValue | moHttpUrl | voiceStatusCallbackUrl
----------------------------------------------------------------------------------------------------------------------------
31555555555 | NL      | mobile-lvn | VOICE,SMS | app               | b6d9f957           | undefined | https://example.com
44655555555 | GB      | mobile-lvn | VOICE,SMS | app               | b6d9f957           | undefined | https://example.com
44555555555 | GB      | mobile-lvn | SMS       | app               | b6d9f957           | undefined | https://example.com
```

Alias: `nexmo nl`, `nexmo numbers` and `nexmo number:list`.

#### Search for new numbers

Parameters:

- `country_code` - an ISO 3166-2 country code for the country you are trying to find a number for.
- Optional flags:

  - `--pattern <pattern>` to be matched in number (use * to match end or start of number)
  - `--voice` to search for voice enabled numbers
  - `--sms` search for SMS enabled numbers
  - `--size` the amount of results to return
  - `--page` the page of results to return

```bash
> nexmo number:search US
12057200555
12069396555
12069396555
12155961555

> nexmo number:search NL --sms --pattern *007 --verbose
msisdn      | country | cost | type       | features
-----------------------------------------------------
31655551007 | NL      | 3.00 | mobile-lvn | VOICE,SMS
31655552007 | NL      | 3.00 | mobile-lvn | VOICE,SMS
31655553007 | NL      | 3.00 | mobile-lvn | VOICE,SMS
```

Alias: `nexmo ns` and `nexmo numbers:search`.

#### Buying a number

Parameters:

- `number` - The number to buy
- or `country_code` and `pattern` - The country and search pattern to find a number for and directly buy.

```bash
> nexmo number:buy 12069396555
Buying 12069396555\. This operation will charge your account.

Please type "confirm" to continue: confirm

Number purchased

> nexmo number:buy US *555
Buying 12069396555\. This operation will charge your account.

Please type "confirm" to continue: confirm

Number purchased: 12069396555

> nexmo number:buy 12069396555 --confirm
Number purchased: 12069396555
```

Alias: `nexmo nb` and `nexmo numbers:buy`.

#### Cancelling a number

```bash
> nexmo number:cancel 12069396555
This is operation can not be reversed.

Please type "confirm" to continue: confirm

Number cancelled: 12069396555

> nexmo number:cancel 12069396555 --confirm
Number cancelled: 12069396555
```

Alias: `nexmo nc` and `nexmo numbers:cancel`.

#### Update a number

For shortcuts of these options see [Linking](#linking).

```bash
> nexmo number:update 445555555555 --voice_callback_type app --voice_callback_value asdasdas-asdd-2344-2344-asdasdasd345
Number updated
```

Alias: `nexmo nu` and `nexmo numbers:update`.

### SMS

#### Send an SMS

Send a message through Nexmo to any number. Either provide a from number, name, or leave it blank to sends as "Nexmo CLI".

```bash
> nexmo sms <destination_number> Hello world! --confirm
Message sent to:   <destination_number>
Remaining balance: 26.80110000 EUR
Message price:     0.03330000 EUR

> nexmo sms  <destination_number> Hello world! --from "Acme Inc" --confirm
Message sent to:   <destination_number>
Remaining balance: 26.80110000 EUR
Message price:     0.03330000 EUR
```

**Note:** Some carriers (e.g. US and Canadian) do not allow alphanumeric senders. In these cases, you must use one of your Nexmo virtual numbers in the `from` parameter. For example:

```bash
nexmo sms <to_number> Hello world! --from <from_number> --confirm
```

### Applications

#### List your Applications

- Optional flags:

  - `--size` The amount of results to return
  - `--page` The page of results to return

```bash
> nexmo app:list
asdasdas-asdd-2344-2344-asdasdasd123 | Test Application 1
asdasdas-asdd-2344-2344-asdasdasd234 | Test Application 1
asdasdas-asdd-2344-2344-asdasdasd345 | Test Application 2

> nexmo app:list --verbose
Item 1-3 of 3

id                                   | name
---------------------------------------------------------
asdasdas-asdd-2344-2344-asdasdasd123 | Test Application 1
asdasdas-asdd-2344-2344-asdasdasd234 | Test Application 1
asdasdas-asdd-2344-2344-asdasdasd345 | Test Application 2
```

Alias: `nexmo al` and `nexmo apps`.

#### Create a new Application

This command has interactive mode available. Run the command without any parameters and an interactive prompt will guide you through creating an application. The interactive mode also outputs the non-interactive command used to generate the application if you need to create the same application again.

For non-interactive mode, parameters are:

- `name` - the custom name of your application.
- `--capabilities capabilities` - the capabilities your application has, as a comma separated list. Can be voice, messages, rtc, vbc.

- Optional flags:
    - `--keyfile <keyfile>` - the file to save your private key to.
    - `--public-keyfile [publicKeyfile]` - the public key for your application.
    - `--voice-event-url [voiceEventUrl]` - the event URL for the voice capability.
    - `--voice-event-method [voiceEventMethod]` - the HTTP method to use for the --voice-event-url (defaults to POST).
    - `--voice-answer-url [voiceAnswerUrl]` - the answer URL for the voice capability.
    - `--voice-answer-method [voiceAnswerMethod]` - the HTTP method to use for the --voice-answer-url (defaults to GET).
    - `--voice-fallback-answer-url [voiceFallbackAnswerUrl]` - the fallback answer URL for the voice capability.
    - `--voice-fallback-answer-method [voiceFallbackAnswerMethod]` - the HTTP method to use for the --voice-fallback-answer-url (defaults to GET).
    - `--messages-inbound-url [messagesInboundUrl]` - the inbound URL for the messages capability.
    - `--messages-status-url [messagesStatusUrl]` - the status URL for the messages capability.
    - `--rtc-event-url [rtcEventUrl]` - the event URL for the rtc capability.
    - `--rtc-event-method [rtcEventMethod]` - the HTTP method to use for the --rtc-event-url (defaults to POST).


```
> nexmo app:create "Test Application V2" --capabilities=voice,messages,rtc,vbc --voice-answer-url=http://example.com --voice-fallback-answer-url=http://example.com --voice-event-url=http://example.com --messages-inbound-url=http://example.com --messages-status-url=http://example.com --rtc-event-url=http://example.com --keyfile=private.key

Application created: asdasdas-asdd-2344-2344-asdasdasd345
Credentials written to /path/to/.nexmo-app

Private Key saved to: /path/to/private.key

> nexmo app:create "Test Application V2" --capabilities=voice,messages,rtc,vbc --voice-answer-url=http://example.com --voice-fallback-answer-url=http://example.com --voice-event-url=http://example.com --messages-inbound-url=http://example.com --messages-status-url=http://example.com --rtc-event-url=http://example.com --keyfile=private.key -v
[id]
asdasdas-asdd-2344-2344-asdasdasd345

[name]
Test Application V2

[keys.private_key]
-----BEGIN PRIVATE KEY-----
...
-----END PRIVATE KEY-----


[keys.public_key]
-----BEGIN PUBLIC KEY-----
...
-----END PUBLIC KEY-----


[capabilities.voice.webhooks.event_url.address]
http://example.com

[capabilities.voice.webhooks.event_url.http_method]
POST

[capabilities.voice.webhooks.answer_url.address]
http://example.com

[capabilities.voice.webhooks.answer_url.http_method]
GET

[capabilities.voice.webhooks.fallback_answer_url.address]
http://example.com

[capabilities.voice.webhooks.fallback_answer_url.http_method]
GET

[capabilities.rtc.webhooks.event_url.address]
http://example.com

[capabilities.rtc.webhooks.event_url.http_method]
POST

[capabilities.messages.webhooks.inbound_url.address]
http://example.com

[capabilities.messages.webhooks.inbound_url.http_method]
POST

[capabilities.messages.webhooks.status_url.address]
http://example.com

[capabilities.messages.webhooks.status_url.http_method]
POST

[_links.self.href]
/v2/applications/asdasdas-asdd-2344-2344-asdasdasd345


Credentials written to /path/to/.nexmo-app
Private Key saved to: /path/to/private.key
```

Alias: `nexmo ac`.

#### Show details for an Application

- Optional flags:
    - `--v2` - use the v2 version of the API.
    - `--recreate` - show the CLI command to create a similar application.


```bash
> nexmo app:show asdasdas-asdd-2344-2344-asdasdasd345
[id]
asdasdas-asdd-2344-2344-asdasdasd345

[name]
Test Application 1

[voice.webhooks.0.endpoint_type]
event_url

[voice.webhooks.0.endpoint]
http://example.com

[voice.webhooks.0.http_method]
POST

[voice.webhooks.1.endpoint_type]
answer_url

[voice.webhooks.1.endpoint]
http://example.com

[voice.webhooks.1.http_method]
GET

[keys.public_key]
...

[_links.self.href]
/applications/asdasdas-asdd-2344-2344-asdasdasd345
```

```bash
> nexmo as asdasdas-asdd-2344-2344-asdasdasd345 --recreate --v2
[id]
asdasdas-asdd-2344-2344-asdasdasd345

[name]
Test Application V2

[keys.public_key]
-----BEGIN PUBLIC KEY-----
...
-----END PUBLIC KEY-----


[capabilities.voice.webhooks.event_url.address]
http://example.com

[capabilities.voice.webhooks.event_url.http_method]
POST

[capabilities.voice.webhooks.answer_url.address]
http://example.com

[capabilities.voice.webhooks.answer_url.http_method]
GET

[capabilities.voice.webhooks.fallback_answer_url.address]
http://example.com

[capabilities.voice.webhooks.fallback_answer_url.http_method]
GET

[capabilities.rtc.webhooks.event_url.address]
http://example.com

[capabilities.rtc.webhooks.event_url.http_method]
POST

[capabilities.messages.webhooks.inbound_url.address]
http://example.com

[capabilities.messages.webhooks.inbound_url.http_method]
POST

[capabilities.messages.webhooks.status_url.address]
http://example.com

[capabilities.messages.webhooks.status_url.http_method]
POST

[_links.self.href]
/v2/applications/asdasdas-asdd-2344-2344-asdasdasd345



Run this command to create a similar application:

nexmo app:create Test Application V2 --capabilities=voice,rtc,messages,vbc --voice-answer-url=http://example.com --voice-fallback-answer-url=http://example.com --voice-event-url=http://example.com --rtc-event-url=http://example.com --messages-inbound-url=http://example.com --messages-status-url=http://example.com
```

Alias: `nexmo as` and `nexmo app`.

#### Setup an Application

Set up your Application ID and private key

Parameters:

- `app_id` - the UUID of your application.
- `private_key` - the private key for your application
- Optional flags:

  - `--global` write config to user root folder `(~/.nexmo-app)` instead of the current folder `(./.nexmo-app)`

```
> nexmo app:setup asdasdas-asdd-2344-2344-asdasdasd345 private.key
Credentials written to /path/to/local/folder/.nexmo-app

```

Alias: `nexmo aset`.

#### Update an Application

This command has interactive mode available. Run the command without just the `app_id` parameter and an interactive prompt will guide you through updating the application.

For non-interactive mode, parameters are:

- `name` - the custom name of your application.
- `app_id` - the UUID of your application.
- `--capabilities capabilities` - the capabilities your application has, as a comma separated list. Can be voice, messages, rtc, vbc.

- Optional flags:
    - `--public-keyfile [publicKeyfile]` - the public key for your application.
    - `--voice-event-url [voiceEventUrl]` - the event URL for the voice capability.
    - `--voice-event-method [voiceEventMethod]` - the HTTP method to use for the --voice-event-url (defaults to POST).
    - `--voice-answer-url [voiceAnswerUrl]` - the answer URL for the voice capability.
    - `--voice-answer-method [voiceAnswerMethod]` - the HTTP method to use for the --voice-answer-url (defaults to GET).
    - `--voice-fallback-answer-url [voiceFallbackAnswerUrl]` - the fallback answer URL for the voice capability.
    - `--voice-fallback-answer-method [voiceFallbackAnswerMethod]` - the HTTP method to use for the --voice-fallback-answer-url (defaults to GET).
    - `--messages-inbound-url [messagesInboundUrl]` - the inbound URL for the messages capability.
    - `--messages-status-url [messagesStatusUrl]` - the status URL for the messages capability.
    - `--rtc-event-url [rtcEventUrl]` - the event URL for the rtc capability.
    - `--rtc-event-method [rtcEventMethod]` - the HTTP method to use for the --rtc-event-url (defaults to POST).
```bash
> nexmo app:update asdasdas-asdd-2344-2344-asdasdasd345 "Test Application V2" --capabilities=voice,rtc,messages,vbc --voice-answer-url=http://example.com --voice-fallback-answer-url=http://example.com --voice-event-url=http://example.com --rtc-event-url=http://example.com --messages-inbound-url=http://example.com --messages-status-url=http://example.com
Application updated: asdasdas-asdd-2344-2344-asdasdasd345

> nexmo app:update asdasdas-asdd-2344-2344-asdasdasd345 "Test Application V2" --capabilities=voice,rtc,messages,vbc --voice-answer-url=http://example.com --voice-fallback-answer-url=http://example.com --voice-event-url=http://example.com --rtc-event-url=http://example.com --messages-inbound-url=http://example.com --messages-status-url=http://example.com -v
[id]
asdasdas-asdd-2344-2344-asdasdasd345

[name]
Test Application V2

[keys.public_key]
-----BEGIN PUBLIC KEY-----
...
-----END PUBLIC KEY-----


[capabilities.voice.webhooks.event_url.address]
http://example.com

[capabilities.voice.webhooks.event_url.http_method]
POST

[capabilities.voice.webhooks.answer_url.address]
http://example.com

[capabilities.voice.webhooks.answer_url.http_method]
GET

[capabilities.voice.webhooks.fallback_answer_url.address]
http://example.com

[capabilities.voice.webhooks.fallback_answer_url.http_method]
GET

[capabilities.rtc.webhooks.event_url.address]
http://example.com

[capabilities.rtc.webhooks.event_url.http_method]
POST

[capabilities.messages.webhooks.inbound_url.address]
http://example.com

[capabilities.messages.webhooks.inbound_url.http_method]
POST

[capabilities.messages.webhooks.status_url.address]
http://example.com

[capabilities.messages.webhooks.status_url.http_method]
POST

[_links.self.href]
/v2/applications/asdasdas-asdd-2344-2344-asdasdasd345
```

Alias: `nexmo au`.

#### Delete an application

Parameters:

- `app_id` - The UUID of your application.

```bash
> nexmo app:delete asdasdas-asdd-2344-2344-asdasdasd345
This is operation can not be reversed.

Please type "confirm" to continue: confirm

Application deleted

> nexmo app:delete asdasdas-asdd-2344-2344-asdasdasd345 --confirm
Application deleted
```

Alias: `nexmo ad`.

#### Show numbers for an application

Parameters:

- `app_id` - The UUID of your application.

- Optional flags:

  - `--size` The amount of results to return
  - `--page` The page of results to return

```bash
> nexmo app:numbers asdasdas-asdd-2344-2344-asdasdasd345
31555555555
44655555555
44555555555

> nexmo app:numbers asdasdas-asdd-2344-2344-asdasdasd345 --verbose
Item 1-3 of 3

msisdn      | country | type       | features  | voiceCallbackType | voiceCallbackValue | moHttpUrl | voiceStatusCallbackUrl
----------------------------------------------------------------------------------------------------------------------------
31555555555 | NL      | mobile-lvn | VOICE,SMS | app               | b6d9f957           | undefined | https://example.com
44655555555 | GB      | mobile-lvn | VOICE,SMS | app               | b6d9f957           | undefined | https://example.com
44555555555 | GB      | mobile-lvn | SMS       | app               | b6d9f957           | undefined | https://example.com
```

Alias: `nexmo an` and `nexmo apps:numbers`.

### Conversations

#### Create a new Conversation

Supports optional payloads:
- `name=<name>` - the unique name of your conversation.
- `display_name=<display_name>` - the custom name of your conversation.

```
> nexmo conversation:create display_name="My Conversation"
Conversation created: CON-asdasdas-asdd-2344-2344-asdasdasd345

> nexmo conversation:create display_name="My Conversation" -v
[id]
CON-asdasdas-asdd-2344-2344-asdasdasd345

[href]
http://conversation.local/v1/conversations/CON-asdasdas-asdd-2344-2344-asdasdasd345

```

Alias: `nexmo cc`.

### Users

#### Create a new User

Supports optional payloads:
- `name=<name>` - the name of your user.

```
> nexmo user:create name=alex
User created: USR-asdasdas-asdd-2344-2344-asdasdasd345

> nexmo user:create name=alex -v
[id]
USR-asdasdas-asdd-2344-2344-asdasdasd345

[href]
http://conversation.local/v1/users/USR-asdasdas-asdd-2344-2344-asdasdasd345

```

Alias: `nexmo uc`.

### Members

#### Add a new Member to a Conversation
Parameters:

- `conversation_id` - the UUID of your conversation.
- Supports payloads:
    - `user_id=<user_id>` - the UUID of your user.
    - `action=<action>` - action to perform on conversation (invite | join | leave)
    - `channel={type:<type>}` - channel type

```
> nexmo member:add CON-asdasdas-asdd-2344-2344-asdasdasd345 user_id=USR-asdasdas-asdd-2344-2344-asdasdasd345 channel='{"type":"app"}' action=join
Member added: MEM-asdasdas-asdd-2344-2344-asdasdasd345

> nexmo member:add CON-asdasdas-asdd-2344-2344-asdasdasd345 user_id=USR-asdasdas-asdd-2344-2344-asdasdasd345 channel='{"type":"app"}' action=join -v
[id]
MEM-asdasdas-asdd-2344-2344-asdasdasd345

[user_id]
USR-asdasdas-asdd-2344-2344-asdasdasd345

[state]
JOINED

[timestamp.joined]
1988-12-12T05:08:27.106Z

[href]
http://conversation.local/v1/conversations/CON-asdasdas-asdd-2344-2344-asdasdasd345/members/MEM-asdasdas-asdd-2344-2344-asdasdasd345


```

Alias: `nexmo ma`.

#### List all Members in a Conversation
Parameters:

- `conversation_id` - the UUID of your conversation.

```
> nexmo member:list CON-asdasdas-asdd-2344-2344-asdasdasd345
MEM-asdasdas-asdd-2344-2344-asdasdasd345 | USR-asdasdas-asdd-2344-2344-asdasdasd345 | NAM-asdasdas-asdd-2344-2344-asdasdasd345 | JOINED

> nexmo member:list CON-asdasdas-asdd-2344-2344-asdasdasd345 -v
name                                     | user_id                                  | user_name                                | state
----------------------------------------------------------------------------------------------------------------------------------------
MEM-asdasdas-asdd-2344-2344-asdasdasd345 | USR-asdasdas-asdd-2344-2344-asdasdasd345 | NAM-asdasdas-asdd-2344-2344-asdasdasd345 | JOINED
```

Alias: `nexmo ml`.

### Linking

#### Link a number to an app

```bash
> nexmo link:app 12057200555 asdasdas-asdd-2344-2344-asdasdasd345
Number updated

> nexmo unlink:app 12057200555
Number updated
```

Alias: `nexmo la`

#### Link a number to another phone number

```bash
> nexmo link:tel 12057200555 4455555555
Number updated

> nexmo unlink:tel 12057200555
Number updated
```

Alias: `nexmo lt`

#### Link a number to an SMS callback URL

```bash
> nexmo link:sms 12057200555 http://example.com/callback
Number updated

> nexmo unlink:sms 12057200555
Number updated
```

Alias: `nexmo lsms`

#### Link a number to SIP URI

```bash
> nexmo link:sip 12057200555 sip:123@example.com
Number updated

> nexmo unlink:sip 12057200555
Number updated
```

Alias: `nexmo lsip`

### Insight

#### Insight Basic

This is the free Number Insight API:

```bash
> nexmo insight:basic 447555555555
447555555555 | GB
```

Alias: `nexmo insight` and `nexmo ib`

#### Insight Standard

This API will charge your account but provide additional details:

```bash
> nexmo insight:standard 447555555555 --confirm
447555555555 | GB | Telefonica UK Limited
```

Verbose mode will return additional information.

Alias: `nexmo is`

#### Insight Advanced

This API will charge your account but provide additional details:

```bash
> nexmo insight:advanced 447555555555 --confirm
447555555555 | GB | Telefonica UK Limited
```

Verbose mode will return additional information.

Alias: `nexmo ia`

### JWT

#### Generate

Generate a JWT for your application. Optionally supports extra claims to be passed in. Can also be used without a private key and `application_id` if there is a local `.nexmo-app` file present.

```bash
> nexmo jwt:generate path/to/private.key subject=username iat=1475861732
[...JWT String...]
> nexmo jwt:generate path/to/private.key subject=username iat=1475861732 application_id=asdasdas-asdd-2344-2344-asdasdasd345
> JWT: [...JWT String...]
> nexmo jwt:generate subject=username iat=1475861732
> JWT: [...JWT String...]
```

## Contributing

This project is written in ES2015 and compiled using Babel. The source can be found in the `/src` folder, and the build is compiled to the `/lib` folder.

To add changes, fork and clone the project.

```bash
npm install        # to install all dependencies
npm run build      # to explicitly build the source
npm install -g ./  # to implicitly build the source, and then install the `nexmo` binary into your PATH
npm test           # to run all tests
npm run watch:test # to watch for changes and run tests
```

You can run the `nexmo` command with the `--debug` / `-d` flag to get extra debug info from the underlying Node.js library.

# License

This library is released under the [MIT License][license]

[license]: LICENSE.txt
